#
# spec file for package fooyin
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           fooyin
Version:        0.7.3
Release:        1.1
Summary:        A customisable music player built with Qt
License:        GPL-3.0-only
URL:            https://github.com/ludouzi/%{name}
Source:         https://github.com/ludouzi/%{name}/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  c++_compiler
BuildRequires:  hicolor-icon-theme
BuildRequires:  qt6-base-devel
BuildRequires:  cmake(KDSingleApplication-qt6)
BuildRequires:  cmake(Qt6Core)
BuildRequires:  cmake(Qt6DBus)
BuildRequires:  cmake(Qt6Linguist)
BuildRequires:  cmake(Qt6LinguistTools)
BuildRequires:  cmake(Qt6OpenGLWidgets)
BuildRequires:  cmake(Qt6Svg)
BuildRequires:  cmake(Qt6Widgets)
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(icu-uc)
BuildRequires:  pkgconfig(libavcodec)
BuildRequires:  pkgconfig(libavdevice)
BuildRequires:  pkgconfig(libavformat)
BuildRequires:  pkgconfig(libavutil)
BuildRequires:  pkgconfig(libpipewire-0.3)
BuildRequires:  pkgconfig(libpostproc)
BuildRequires:  pkgconfig(libswresample)
BuildRequires:  pkgconfig(libswscale)
BuildRequires:  pkgconfig(taglib)
BuildRequires:  pkgconfig(xkbcommon)

%description
fooyin is a Qt6 music player built around customisation. It offers a
growing list of widgets to manage and play a local music collection.
It is extendable through the use of plugins, and many widgets make
use of FooScript to offer an even deeper level of control.

%prep
%autosetup -p1

%build
%cmake -DBUILD_LIBVGM=OFF
%cmake_build

%install
%cmake_install
# No header files were installed, so... no point in keeping the
# component libraries' devel files.
rm -fv %{buildroot}/%{_libdir}/fooyin/*.so

%files
%license COPYING
%doc README.md
%{_bindir}/%{name}
%{_datadir}/applications/*
%{_datadir}/doc/%{name}
%{_datadir}/metainfo/*
%{_datadir}/icons/hicolor/*/apps/org.%{name}.%{name}.*
%{_datadir}/%{name}
%{_libdir}/%{name}/

%changelog
* Sat Sep 28 2024 Julius Enriquez <win8linux@gmail.com>
- Update to upstream 0.7.3
  * Improvements
  * Decoding: Support vgm7z
  * Properties: Improve appearance
  * Fixes
  * Decoding: Resolve crash when restarting playback of some decoders
  * Layout: Resolve crash when leaving layout editing mode
- Release notes for interim release 0.7.2 can be found here:
  https://github.com/fooyin/fooyin/releases/tag/v0.7.2
* Sat Sep 21 2024 Julius Enriquez <win8linux@gmail.com>
- Update to upstream 0.7.1
  * Improvements
  * Interface: Add option to lock splitters
  * OpenMpt: Add config dialog
  * ScriptEditor: Open with currently selected track if available
  * Fixes
  * Interface: Fix a few misspellings
  * ScriptFormatter: Fix parsing of '<' in metadata fields
  * SelectionInfo: Fix empty model on some systems
  * TagEditor: Fix changing rating
* Fri Sep 20 2024 Julius Enriquez <win8linux@gmail.com>
- Update to upstream 0.7.0
  * New features
  * ReplayGain support
  * Adds support for reading and applying RG info
  * Scrobbling
  * Last.fm and ListenBrainz are currently supported
  * Improvements
  * General
  * Support multiple values for composer, performer
  * Store additional fields: codec profile, encoding, tool, tag types
  * Interface
  * FontButton: Apply set font to button text
  * Show dynamic bitrate in status bar for vbr/abr tracks
  * ToolTip: Improve positioning
  * Volume: Add slider dB tooltip
  * Scripting
  * Improve implementation of $abbr and $replace
  * Add $ascii function
  * SelectionInfo
  * Add optional ReplayGain section
  * Hide empty entries
  * Engine: Handle audio samples as float64
  * FileOps: Replace directory separators in variable calls
  * PlaylistOrganiser: Support dropping tracks on existing playlists
  * TagEditor: Support customising default fields
  * Fixes
  * Interface
  * Resolve crash when changing layouts
  * Fix fonts not being set correctly on startup
  * Fix painting alternating row colours
  * Fix toggling selection in some views
  * LogSlider: Fix undefined behaviour
  * SeekBar: Fix some fonts causing widget to resize
  * Engine
  * Fix playback not pausing while muted
  * Fix listened duration carrying over to next track
  * Fix track always being considered played when restoring state on startup
  * Filters
  * Fix incorrect item width on startup
  * Fix page up/down in artwork mode
  * PlaylistOrganiser
  * Resolve crash when deleting active playlist
  * Fix shortcuts not working after right-click
  * General: Fix building with Qt6.8
  * Library: Notify of updated tracks while reloading
  * Scripting: Support split values with $swapprefix, $stripprefix
  * Selection Info: Fix sorting of entries
  * WaveBar: Fix restoring playing/paused state
* Thu Sep 12 2024 Julius Enriquez <win8linux@gmail.com>
- Update to upstream 0.6.2
  * New features
  * Theme support
  * Ability to change palette colours and fonts
  * Includes dark mode theme
  * Option to save to layouts on export
  * Improvements
  * Filters: Enable library viewer playlist by default
  * Scripting: Make variable calls case-insensitive
  * Settings: Add page to toggle and adjust order of decoders/tag readers
  * VolumeControl: Support enabling both icon and slider
  * Fixes
  * Controls: Fix volume slider resizing splitter
  * Engine: Fix crash when reading short archive entries
  * ExpandedTreeView: Fix setting uniform row heights
  * Playlist
  * Fix crash when switching to single-column mode
  * Fix track repeating with shuffle + repeat playlist enabled
  * Fix some rare instances of duplicate tracks
  * Fix auto-naming of new playlists for tracks with limited metadata
  * Search: Fix sorting by column
- Release notes for interim release 0.6.1 can be found here:
  https://github.com/fooyin/fooyin/releases/tag/v0.6.1
- Release notes for interim release 0.6.0 can be found here:
  https://github.com/fooyin/fooyin/releases/tag/v0.6.0
* Mon Jul  8 2024 Julius Enriquez <win8linux@gmail.com>
- Update to upstream 0.5.3
  * Fixes
  * LibraryScanner
  * Fix reading file properties for external files
  * Fix reading duration for cue tracks
  * Playlist: Fix start playback on send to new playlist failing
- Release notes for interim release 0.5.2 can be found here:
  https://github.com/fooyin/fooyin/releases/tag/v0.5.2
* Sun Jun 30 2024 Julius Enriquez <win8linux@gmail.com>
- Update to upstream 0.5.1
  * Improvements
  * Playback
  * Add option to silently continue playback if track unavailable
  * Show message box for ALSA device errors
  * Library Tree: Make animation of expand/collapse configurable
  * Volume Control: Add slider mode
  * Fixes
  * Playlist
  * Fix unscrollable view when changing playlist
  * Fix selection playlists refreshing during library scans
  * Engine: Fix silence when resuming from a stopped state with fading enabled
  * ExpandedTreeView: Stop autoscrolling to selection if partly visible
  * Filters: Fix restoring selection on track update
  * Library Tree: Fix text colour for playing row
  * Scripting: Fix usage of custom tags
- Release notes for interim release 0.5.0 can be found here:
  https://github.com/ludouzi/fooyin/releases/tag/v0.5.0
* Thu Jun  6 2024 Julius Enriquez <win8linux@gmail.com>
- Update to upstream release 0.4.5
  * Fixes
  * Fix playback on startup if current output not found
  * Fix pause not pausing playback position
- Release notes for interim release 0.4.4 can be found here:
  https://github.com/ludouzi/fooyin/releases/tag/v0.4.4
* Wed May 29 2024 Julius Enriquez <win8linux@gmail.com>
- Update to new upstream release 0.4.3
  * Improvements
  * Interface
  * Support changing volume by scrolling on volume icon
  * Add options to control appearance of tool buttons
  * Add options to override margins, splitter handle sizes
  * Make quick setup dialog modal
  * Playlist
  * Add channels column
  * Add last modified column
  * Improve performance when updating playback statistics
  * WaveBar
  * Add optional labels
  * Improve behaviour when seeking
  * Fixes
  * Refer to the upstream release notes for more details on fixes: https://github.com/ludouzi/fooyin/releases/tag/v0.4.3
- Removed QCoro dependency
  * See https://github.com/ludouzi/fooyin/commit/c5aa3620c2d78a70e3d10d06d8fb0ed6ce4cb041
- Icon name changed to reverse DNS format
  * Part of a commit to use more reverse DNS: https://github.com/ludouzi/fooyin/commit/fab7933ced4347d7593c1ea378ebe56081d930a5
* Sun May 26 2024 Julius Enriquez <win8linux@gmail.com>
- Working spec file
* Thu May 23 2024 Julius Enriquez <win8linux@gmail.com>
- Initial spec file
